<?php
/**
 * Ce fichier contient les autorisations nécessaire à la gestion de l'archivage des objets.
 *
 * @package SPIP\ARCHOBJET\AUTORISATIONS
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}
/**
 * Fonction vide pour le pipeline homonyme.
 *
 * @return void
 */
function archobjet_autoriser() {}

/**
 * Autorisation de base pour l'archivage d'un type de contenu.
 * - l'objet doit être archivable
 *
 * @param string          $faire   Action demandée : archivage
 * @param string          $type    Type d'objet ou élément
 * @param int|string|null $id      Identifiant du taxon : inutilisé
 * @param array           $qui     Description de l'auteur demandant l'autorisation
 * @param array           $options Options de cette autorisation : inutilisé
 *
 * @return bool `true` si l'autorisation est donnée, `false` sinon
**/
function autoriser_archivage_dist($faire, $type, $id, $qui, $options) {

	$autoriser = false;
	if ($type) {
		// Lecture des tables autorisées à l'archivage
		include_spip('inc/config');
		$tables_autorisees = lire_config('archobjet/objets_archivables', array());

		// Rechercher la table associée au type d'objet
		include_spip('base/objets');
		$table = table_objet_sql($type);

		// Si l'objet est archivable et que l'utilisateur est un administrateur non restreint on autorise l'archivage.
		if (
			$table
			and in_array($table, $tables_autorisees)
		) {
			$autoriser = true;
		}
	}

	return $autoriser;
}

/**
 * Autorisation d'archiver, de désarchiver ou de modifier la raison d'archivage d'un objet donné.
 * - l'archivage doit être autorisé sur le type d'objet
 * - l'utilisateur doit être un administrateur complet.
 * - et l'objet ne doit pas être dans l'état consécutif à l'action demandée.
 *
 * @param string          $faire   Action demandée : modifierarchivage, à savoir, archiver, désarchiver ou modifier la raison.
 * @param string          $type    Type d'objet ou élément
 * @param int|string|null $id      Identifiant de l'objet
 * @param array           $qui     Description de l'auteur demandant l'autorisation
 * @param array           $options Options de cette autorisation : l'index 'action' qui vaut `archiver` ou `desarchiver`
 *                                 ou `modifier_raison`
 *
 * @return bool `true` si l'autorisation est donnée, `false` sinon
**/
function autoriser_modifierarchivage_dist($faire, $type, $id, $qui, $options) {
	$autoriser = false;

	if (
		autoriser('archivage', $type)
		and autoriser('defaut')
		and $type
		and ($id_objet = intval($id))
		and isset($options['action'])
	) {
		// Vérification de l'état d'archivage
		include_spip('inc/archobjet');
		$etat_archivage = archivage_lire_etat_objet(
			$type,
			$id_objet
		);

		$action = $options['action'];
		if (
			(
				($action == 'archiver')
				and !$etat_archivage['est_archive']
			)
			or (
				($action == 'desarchiver')
				and $etat_archivage['est_archive']
			)
			or ($action == 'modifier_raison')
		) {
			$autoriser = true;
		}
	}

	return $autoriser;
}
